Renoir changelog
================

Version 1.8
-----------

*Released on October 12th 2024*

- Added Python 3.13 support

Version 1.7
-----------

*Released on October 18th 2023*

- Removed Python 3.7 support
- Added Python 3.12 support

Version 1.6
-----------

*Released on December 18th 2022*

- Added support for structural pattern matching (`match`/`case` statements)
- Removed Python 3.6 support
- Added Python 3.11 support

Version 1.5
-----------

*Released on October 8th 2021*

- Added Python 3.10 support
- Added (experimental) support for multiple `include` no-argument lexer parsing

Version 1.4
-----------

*Released on June 1st 2021*

- Added `delimiters` parameter to `Renoir` constructor

Version 1.3
-----------

*Released on November 27th 2020*

- Added support for relative paths in `extend`, `include` lexers
- Added Python 3.9 support

Version 1.2
-----------

*Released on April 3rd 2020*

- Refactored parser
- Added `plain` mode
- Removed `prettify` option in favour of `adjust_indent`

Version 1.1
-----------

*Released on March 15th 2020*

- Added type hints on main interfaces
- Updated documentation

Version 1.0
-----------

*Released on January 13th 2020*

First public release
